==> unify_api-1.2.0.tar.gz: lib/src/client.dart <==
part of unify;

abstract class UnifyClient {
  factory UnifyClient(String email, String password,
      {UnifyApiEndpoints endpoints, UnifyAccessToken token, String domain}) {
    return UnifyClientImpl(email, password, token,
        endpoints == null ? UnifyApiEndpoints.standard(domain) : endpoints);
  }

  String get email;
  String get password;

  UnifyAccessToken get token;
  set token(UnifyAccessToken token);

  bool get isAuthorized;

  UnifyApiEndpoints get endpoints;

  Future login();

  Future logout();

  Future<AccountInfo> getInfo();

  /// **Slow** - Fetches Totals for All Lists
  Future<AccountStats> getTotals();

  Future<UnifyCache> getCache({bool all = false});

  Future<AccountInfo> getUser(String id);

  Future<List<Contact>> listContacts(
      {int page = 1, int rows = 100, String query = ""});

  Future<ContactDetails> getContactDetails(String id);

  Future<List<ContactNote>> listContactNotes(String id);

  Future<List<Timeline>> listContactTimeline(String id);

  Future addContactNote(String id, String text);

  Future addContactGroup(String name);

  Future editContactGroup(String id, String name);

  Future addLeadGroup(String name);

  Future editLeadGroup(String id, String name);

  Future deleteContactGroup(String id);

  Future deleteLeadGroup(String id);

  Future editContact(
    String id, {
    @required String firstName,
    @required String lastName,
    String middleName,
    String suffix,
    String secondaryFirstName,
    String secondaryMiddleName,
    String secondaryLastName,
    PostalAddress currentAddress,
    PhoneNumber cellPhone,
    PhoneNumber homePhone,
    PhoneNumber officePhone,
    PhoneNumber faxPhone,
    PhoneNumber secondaryCellPhone,
    String email,
    String secondaryEmail,
    String loanNumber,
    int contactPriority,
    CompanyCategory companyCategory,
    List<ContactGroup> groups,
  });

  Future addContact({
    @required String firstName,
    @required String lastName,
    String middleName,
    String suffix,
    String secondaryFirstName,
    String secondaryMiddleName,
    String secondaryLastName,
    PostalAddress currentAddress,
    PhoneNumber cellPhone,
    PhoneNumber homePhone,
    PhoneNumber officePhone,
    PhoneNumber faxPhone,
    PhoneNumber secondaryCellPhone,
    String email,
    String secondaryEmail,
    String loanNumber,
    int contactPriority,
    CompanyCategory companyCategory,
    List<ContactGroup> groups,
  });

  Future editLead(
    String id, {
    @required String firstName,
    @required String lastName,
    String middleName,
    String suffix,
    String secondaryFirstName,
    String secondaryMiddleName,
    String secondaryLastName,
    PostalAddress currentAddress,
    PostalAddress propertyAddress,
    PhoneNumber cellPhone,
    PhoneNumber homePhone,
    PhoneNumber officePhone,
    PhoneNumber faxPhone,
    PhoneNumber secondaryCellPhone,
    String email,
    List<LeadGroup> groups,
    String bestCallTime,
    String creditRange,
    String secondaryCreditRange,
    double annualGrossIncome,
    bool recentBankruptcy,
    double propertyValue,
  });

  Future addLead({
    @required String firstName,
    @required String lastName,
    String middleName,
    String suffix,
    String secondaryFirstName,
    String secondaryMiddleName,
    String secondaryLastName,
    PostalAddress currentAddress,
    PostalAddress propertyAddress,
    PhoneNumber cellPhone,
    PhoneNumber homePhone,
    PhoneNumber officePhone,
    PhoneNumber faxPhone,
    PhoneNumber secondaryCellPhone,
    String email,
    List<LeadGroup> groups,
    String bestCallTime,
    String creditRange,
    String secondaryCreditRange,
    double annualGrossIncome,
    bool recentBankruptcy,
    double propertyValue,
  });

  Future addContactLogResponse(String id,
      {@required String action, String comment});

  Future addLeadLogResponse(String id,
      {@required String action, String comment});

  /// type: `0 (Task)`, `1 (Appointment)`, `2 (Scheduled Call)`
  ///
  /// alertType: `Email`, `TextMessage`, `Email, TextMessage`, ""
  ///
  /// alertOffset: int for `minutes`
  Future addContactFollowUp(
    String id, {
    @required String title,
    DateTime date,
    int type = 0,
    String description = "",
    bool dismissOnChange = true,
    String alertType,
    int alertOffset = 0,
    String userNumber,
    String prospectNumber,
  });

  /// type: `0 (Task)`, `1 (Appointment)`, `2 (Scheduled Call)`
  ///
  /// alertType: `Email`, `TextMessage`, `Email, TextMessage`, ""
  ///
  /// alertOffset: int for `minutes`
  Future addLeadFollowUp(
    String id, {
    @required String title,
    DateTime date,
    int type = 0,
    String description = "",
    bool dismissOnChange = true,
    String alertType,
    int alertOffset = 0,
    String userNumber,
    String prospectNumber,
  });

  Future<List<Lead>> listLeads(
      {int page = 1, int rows = 100, String query = ""});

  Future<LeadDetails> getLeadDetails(String id);

  Future<List<LeadNote>> listLeadNotes(String id);

  Future<List<Timeline>> listLeadTimeline(String id);

  Future addLeadNote(String id, String text);

  Future<List<DashboardAlert>> listOpportunitiyAlerts(
      {int page = 1, int rows = 100});

  Future<List<DashboardAlert>> listCustomerAlerts(
      {int page = 1, int rows = 100});

  Future<List<DashboardAlert>> listHotProspectAlerts(
      {int page = 1, int rows = 100});

  Future<List<DashboardAlert>> listPipelineAlerts(
      {int page = 1, int rows = 100});

  Future<List<DashboardPartners>> listDashboardPartners(
      {int page = 1, int rows = 100});

  Future<List<ContactGroup>> listContactGroups({bool totals = true});

  Future<List<LeadGroup>> listLeadGroups({bool totals = true});

  Future<List<Contact>> listContactsForContactGroup(String id,
      {int page = 1, int rows = 100, String query = ""});

  Future<List<Lead>> listLeadsForLeadGroup(String id,
      {int page = 1, int rows = 100, String query = ""});

  Future<List<String>> listEmailsForContactGroup(String id);

  Future<List<String>> listEmailsForLeadGroup(String id);

  Future<List<Loan>> listLoans({
    int page = 1,
    int rows = 100,
    String query = '',
    LoansFolder folder = LoansFolder.all,
  });

  Future<LoanDetails> getLoanDetails(String id);

  Future<List<Task>> listTasksContacts({DateTime date});

  Future<List<Task>> listTasksLeads({DateTime date});

  Future<List<Task>> listTasksAll({DateTime date});

  Future<List<Task>> listTasksForContact(String id, {DateTime date});

  Future<List<Task>> listTasksForLead(String id, {DateTime date});

  Future<List<Task>> listTasksForCoreLead(String id, {DateTime date});

  Future<List<Task>> listTasksCoreLeads({DateTime date});

  Future<List<CoreLead>> listCoreLeads(
      {int page = 1, int rows = 100, String query = ""});

  Future<CoreLeadDetails> getCoreLeadDetails(String id);

  Future<DashboardStats> getStats();

  Future<LoanProgress> getLoanStatus(String id);

  Future<List<LoanContact>> listLoanContacts(String id);

  Future<List<LoanHistory>> listLoanHistory(String id);

  Future<List<String>> listContactLogResponses();

  Future<List<String>> listLeadLogResponses();

  Future<List<CompanyCategory>> listCompanyCategories();

  Future<List<String>> listTemplates();

  Future<List<MarketingSection>> listMarketingSection();

  Future<List<MarketingMaterial>> listMarketingMaterial(
      {String type, String category, String subCategory, String query = ""});

  Future<MarketingMaterialDetails> getMarketingDetails(String id);

  Future<List<MarketingCampaign>> listMarketingCampaigns(
      {int page = 1, int rows = 100});

  Future deleteMarketingCampiagn(String id);

  Future<List<MarketingPartner>> listMarketingPartners();

  Future<String> getVideoPreview(
    String id, {
    String name,
    String body,
    String template,
  });

  Future startVideoQuickSend(
    String id, {
    bool cc,
    @required List<String> emails,
    String subject,
    String body,
    String name,
    String template,
  });

  Future<String> getVideoShareUrl(String id, {String template = "MESSAGE"});

  Future deleteDashboardAlert(String id);

  Future restoreDashboardAlert(String id);

  Future deleteContact(String id);

  Future deleteLead(String id);

  Future deleteTask(String id);

  Future deleteCartItem(String id);

  Future deleteCartCard(String id);

  Future batchDeleteContacts(List<Contact> contacts);

  Future batchRestoreContacts(List<Contact> contacts);

  Future batchRestoreLeads(List<Lead> leads);

  Future batchDeleteLeads(List<Lead> leads);

  Future batchRestoreDashboardAlerts(List<DashboardAlert> alerts);

  Future batchDeleteDashboardAlerts(List<DashboardAlert> alerts);

  Future<CartOrder> getCartOrder();

  Future<List<CartItem>> listCartItems();

  Future<MarketingValidation> getMarketingValidation(
    String id, {
    String partnerId,
    bool sendNow,
    DateTime startDate,
    List<String> contactIds,
    List<String> leadIds,
  });

  Future startMarketingCampaign(
    String id, {
    String partnerId,
    bool sendNow,
    DateTime startDate,
    List<String> contactIds,
    List<String> leadIds,
  });

  Future addMarketingCampaignToCart(
    String id, {
    String partnerId,
    bool sendNow,
    DateTime startDate,
    List<String> contactIds,
    List<String> leadIds,
  });

  Future<List<UnifyAlert>> listUnifyAlerts(
      {String type, String priority, DateTime date});

  Future deleteUnifyAlert(String id);

  Future<String> getAccountStatus({
    @required String username,
    @required String password,
  });

  Future<num> getAccountBalance();

  Future<List<Video>> listVideosAll(
      {int page = 1, int rows = 100, String query = ""});

  Future<List<Video>> listVideosMyVideos(
      {int page = 1, int rows = 100, String query = ""});

  Future<List<Video>> listVideosShared(
      {int page = 1, int rows = 100, String query = ""});

  Future<List<Video>> listVideosArchived(
      {int page = 1, int rows = 100, String query = ""});

  Future<VideoDetails> getVideoDetails(String id);

  Future<String> getKalturaSession(String kalturaID, {bool admin = false});

  Future<int> getVideoTotalViews();

  // /// BETA: Upload Video Thumbnail
  // Future uploadVideoThumbnail(String id, File image);

  // /// BETA: Upload Video
  // Future uploadVideo(File video,
  //     {@required String name, @required String description});

  Future editVideoInfo(String id, {String name, String description});

  Future close();
}

enum LoansFolder { all, closed, other, activeloans, prospects, mypipeline }

==> unify_api-1.2.3.tar.gz: lib/src/client.dart <==
part of unify;

abstract class UnifyClient {
  factory UnifyClient(String email, String password,
      {UnifyApiEndpoints endpoints, UnifyAccessToken token, String domain}) {
    return UnifyClientImpl(email, password, token,
        endpoints == null ? UnifyApiEndpoints.standard(domain) : endpoints);
  }

  String get email;
  String get password;

  UnifyAccessToken get token;
  set token(UnifyAccessToken token);

  bool get isAuthorized;

  UnifyApiEndpoints get endpoints;

  Future login();

  Future logout();

  Future<AccountInfo> getInfo();

  /// **Slow** - Fetches Totals for All Lists
  Future<AccountStats> getTotals();

  Future<UnifyCache> getCache({bool all = false});

  Future<AccountInfo> getUser(String id);

  Future<List<Contact>> listContacts(
      {int page = 1, int rows = 100, String query = "", bool all = false});

  Future<ContactDetails> getContactDetails(String id);

  Future<List<ContactNote>> listContactNotes(String id);

  Future<List<Timeline>> listContactTimeline(String id);

  Future addContactNote(String id, String text);

  Future addContactGroup(String name);

  Future editContactGroup(String id, String name);

  Future addLeadGroup(String name);

  Future editLeadGroup(String id, String name);

  Future deleteContactGroup(String id);

  Future deleteLeadGroup(String id);

  Future editContact(
    String id, {
    @required String firstName,
    @required String lastName,
    String middleName,
    String suffix,
    String secondaryFirstName,
    String secondaryMiddleName,
    String secondaryLastName,
    PostalAddress currentAddress,
    PhoneNumber cellPhone,
    PhoneNumber homePhone,
    PhoneNumber officePhone,
    PhoneNumber faxPhone,
    PhoneNumber secondaryCellPhone,
    String email,
    String secondaryEmail,
    String loanNumber,
    int contactPriority,
    CompanyCategory companyCategory,
    List<ContactGroup> groups,
  });

  Future addContact({
    @required String firstName,
    @required String lastName,
    String middleName,
    String suffix,
    String secondaryFirstName,
    String secondaryMiddleName,
    String secondaryLastName,
    PostalAddress currentAddress,
    PhoneNumber cellPhone,
    PhoneNumber homePhone,
    PhoneNumber officePhone,
    PhoneNumber faxPhone,
    PhoneNumber secondaryCellPhone,
    String email,
    String secondaryEmail,
    String loanNumber,
    int contactPriority,
    CompanyCategory companyCategory,
    List<ContactGroup> groups,
  });

  Future editLead(
    String id, {
    @required String firstName,
    @required String lastName,
    String middleName,
    String suffix,
    String secondaryFirstName,
    String secondaryMiddleName,
    String secondaryLastName,
    PostalAddress currentAddress,
    PostalAddress propertyAddress,
    PhoneNumber cellPhone,
    PhoneNumber homePhone,
    PhoneNumber officePhone,
    PhoneNumber faxPhone,
    PhoneNumber secondaryCellPhone,
    String email,
    List<LeadGroup> groups,
    String bestCallTime,
    String creditRange,
    String secondaryCreditRange,
    double annualGrossIncome,
    bool recentBankruptcy,
    double propertyValue,
  });

  Future addLead({
    @required String firstName,
    @required String lastName,
    String middleName,
    String suffix,
    String secondaryFirstName,
    String secondaryMiddleName,
    String secondaryLastName,
    PostalAddress currentAddress,
    PostalAddress propertyAddress,
    PhoneNumber cellPhone,
    PhoneNumber homePhone,
    PhoneNumber officePhone,
    PhoneNumber faxPhone,
    PhoneNumber secondaryCellPhone,
    String email,
    List<LeadGroup> groups,
    String bestCallTime,
    String creditRange,
    String secondaryCreditRange,
    double annualGrossIncome,
    bool recentBankruptcy,
    double propertyValue,
  });

  Future addContactLogResponse(String id,
      {@required String action, String comment});

  Future addLeadLogResponse(String id,
      {@required String action, String comment});

  /// type: `0 (Task)`, `1 (Appointment)`, `2 (Scheduled Call)`
  ///
  /// alertType: `Email`, `TextMessage`, `Email, TextMessage`, ""
  ///
  /// alertOffset: int for `minutes`
  Future addContactFollowUp(
    String id, {
    @required String title,
    DateTime date,
    int type = 0,
    String description = "",
    bool dismissOnChange = true,
    String alertType,
    int alertOffset = 0,
    String userNumber,
    String prospectNumber,
  });

  /// type: `0 (Task)`, `1 (Appointment)`, `2 (Scheduled Call)`
  ///
  /// alertType: `Email`, `TextMessage`, `Email, TextMessage`, ""
  ///
  /// alertOffset: int for `minutes`
  Future addLeadFollowUp(
    String id, {
    @required String title,
    DateTime date,
    int type = 0,
    String description = "",
    bool dismissOnChange = true,
    String alertType,
    int alertOffset = 0,
    String userNumber,
    String prospectNumber,
  });

  Future<List<Lead>> listLeads(
      {int page = 1, int rows = 100, String query = "", bool all = false});

  Future<LeadDetails> getLeadDetails(String id);

  Future<List<LeadNote>> listLeadNotes(String id);

  Future<List<Timeline>> listLeadTimeline(String id);

  Future addLeadNote(String id, String text);

  Future<List<DashboardAlert>> listOpportunitiyAlerts(
      {int page = 1, int rows = 100, bool all = false});

  Future<List<DashboardAlert>> listCustomerAlerts(
      {int page = 1, int rows = 100, bool all = false});

  Future<List<DashboardAlert>> listHotProspectAlerts(
      {int page = 1, int rows = 100, bool all = false});

  Future<List<DashboardAlert>> listPipelineAlerts(
      {int page = 1, int rows = 100, bool all = false});

  Future<List<DashboardPartners>> listDashboardPartners(
      {int page = 1, int rows = 100, bool all = false});

  Future<List<ContactGroup>> listContactGroups({bool totals = true});

  Future<List<LeadGroup>> listLeadGroups({bool totals = true});

  Future<List<Contact>> listContactsForContactGroup(String id,
      {int page = 1, int rows = 100, String query = ""});

  Future<List<Lead>> listLeadsForLeadGroup(String id,
      {int page = 1, int rows = 100, String query = ""});

  Future<List<String>> listEmailsForContactGroup(String id);

  Future<List<String>> listEmailsForLeadGroup(String id);

  Future<List<Loan>> listLoans(
      {int page = 1,
      int rows = 100,
      String query = '',
      LoansFolder folder = LoansFolder.all,
      bool all = false});

  Future<LoanDetails> getLoanDetails(String id);

  Future<List<Task>> listTasksContacts({DateTime date});

  Future<List<Task>> listTasksLeads({DateTime date});

  Future<List<Task>> listTasksAll({DateTime date});

  Future<List<Task>> listTasksForContact(String id, {DateTime date});

  Future<List<Task>> listTasksForLead(String id, {DateTime date});

  Future<List<Task>> listTasksForCoreLead(String id, {DateTime date});

  Future<List<Task>> listTasksCoreLeads({DateTime date});

  Future<List<CoreLead>> listCoreLeads(
      {int page = 1, int rows = 100, String query = ""});

  Future<CoreLeadDetails> getCoreLeadDetails(String id);

  Future<DashboardStats> getStats();

  Future<LoanProgress> getLoanStatus(String id);

  Future<List<LoanContact>> listLoanContacts(String id);

  Future<List<LoanHistory>> listLoanHistory(String id);

  Future<List<String>> listContactLogResponses();

  Future<List<String>> listLeadLogResponses();

  Future<List<CompanyCategory>> listCompanyCategories();

  Future<List<String>> listTemplates();

  Future<List<MarketingSection>> listMarketingSection();

  Future<List<MarketingMaterial>> listMarketingMaterial(
      {String type, String category, String subCategory, String query = ""});

  Future<MarketingMaterialDetails> getMarketingDetails(String id);

  Future<MarketingPreview> getMarketingPreview(String id);

  Future<List<MarketingCampaign>> listMarketingCampaigns(
      {int page = 1, int rows = 100});

  Future deleteMarketingCampiagn(String id);

  Future<List<MarketingPartner>> listMarketingPartners();

  Future<String> getVideoPreview(
    String id, {
    String name,
    String body,
    String template,
  });

  Future startVideoQuickSend(
    String id, {
    bool cc,
    @required List<String> emails,
    String subject,
    String body,
    String name,
    String template,
  });

  Future<String> getVideoShareUrl(String id, {String template = "MESSAGE"});

  Future deleteDashboardAlert(String id);

  Future restoreDashboardAlert(String id);

  Future deleteContact(String id);

  Future deleteLead(String id);

  Future deleteTask(String id);

  Future deleteCartItem(String id);

  Future deleteCartCard(String id);

  Future batchDeleteContacts(List<Contact> contacts);

  Future batchRestoreContacts(List<Contact> contacts);

  Future batchRestoreLeads(List<Lead> leads);

  Future batchDeleteLeads(List<Lead> leads);

  Future batchRestoreDashboardAlerts(List<DashboardAlert> alerts);

  Future batchDeleteDashboardAlerts(List<DashboardAlert> alerts);

  Future<CartOrder> getCartOrder();

  Future<List<CartItem>> listCartItems();

  Future<MarketingValidation> getMarketingValidation(
    String id, {
    String partnerId,
    bool sendNow,
    DateTime startDate,
    List<String> contactIds,
    List<String> leadIds,
  });

  Future startMarketingCampaign(
    String id, {
    String partnerId,
    bool sendNow,
    DateTime startDate,
    List<String> contactIds,
    List<String> leadIds,
  });

  Future addMarketingCampaignToCart(
    String id, {
    String partnerId,
    bool sendNow,
    DateTime startDate,
    List<String> contactIds,
    List<String> leadIds,
  });

  Future<List<UnifyAlert>> listUnifyAlerts(
      {String type, String priority, DateTime date});

  Future deleteUnifyAlert(String id);

  Future<String> getAccountStatus({
    @required String username,
    @required String password,
  });

  Future<num> getAccountBalance();

  Future<List<Video>> listVideosAll(
      {int page = 1, int rows = 100, String query = ""});

  Future<List<Video>> listVideosMyVideos(
      {int page = 1, int rows = 100, String query = "", bool showUnapproved = false});

  Future<List<Video>> listVideosShared(
      {int page = 1, int rows = 100, String query = ""});

  Future<List<Video>> listVideosArchived(
      {int page = 1, int rows = 100, String query = ""});

  Future<VideoDetails> getVideoDetails(String id);

  Future<String> getKalturaSession(String kalturaID, {bool admin = false});

  Future<int> getVideoTotalViews();

  // /// BETA: Upload Video Thumbnail
  // Future uploadVideoThumbnail(String id, File image);

  // /// BETA: Upload Video
  // Future uploadVideo(File video,
  //     {@required String name, @required String description});

  Future editVideoInfo(String id, {String name, String description});

  Future close();
}

enum LoansFolder { all, closed, other, activeloans, prospects, mypipeline }
